@@ -59,7 +59,8 @@ module GitHub.Data (
     module GitHub.Data.Statuses,
     module GitHub.Data.Teams,
     module GitHub.Data.URL,
-    module GitHub.Data.Webhooks
+    module GitHub.Data.Webhooks,
+    module GitHub.Data.Webhooks.Validate,
     ) where
 
 import GitHub.Internal.Prelude
@@ -94,6 +95,7 @@ import GitHub.Data.Statuses
 import GitHub.Data.Teams
 import GitHub.Data.URL
 import GitHub.Data.Webhooks
+import GitHub.Data.Webhooks.Validate
 
 mkOwnerId :: Int -> Id Owner
 mkOwnerId = Id
