@@ -89,3 +89,35 @@ instance FromJSON GistComment where
         <*> o .: "body"
         <*> o .: "updated_at"
         <*> o .: "id"
+
+data NewGist = NewGist
+    { newGistDescription :: !(Maybe Text)
+    , newGistFiles       :: !(HashMap Text NewGistFile)
+    , newGistPublic      :: !(Maybe Bool)
+    } deriving (Show, Data, Typeable, Eq, Generic)
+
+instance NFData NewGist where rnf = genericRnf
+instance Binary NewGist
+
+instance ToJSON NewGist where
+    toJSON NewGist { newGistDescription = description
+                   , newGistFiles       = files
+                   , newGistPublic      = public
+                   } = object $ filter notNull
+                   [ "description"      .= description
+                   , "files"            .= files
+                   , "public"           .= public
+                   ]
+      where
+        notNull (_, Null) = False
+        notNull (_, _)    = True
+
+data NewGistFile = NewGistFile
+    { newGistFileContent :: !Text
+    } deriving (Show, Data, Typeable, Eq, Generic)
+
+instance NFData NewGistFile where rnf = genericRnf
+instance Binary NewGistFile
+
+instance ToJSON NewGistFile where
+    toJSON (NewGistFile c) = object ["content" .= c]
