@@ -80,8 +80,7 @@ import Control.Monad.Catch        (MonadCatch (..), MonadThrow)
 import Control.Monad.Trans.Class  (lift)
 import Control.Monad.Trans.Except (ExceptT (..), runExceptT)
 import Data.Aeson                 (eitherDecode)
-import Data.List                  (find, intercalate)
-import Data.String                (fromString)
+import Data.List                  (find)
 import Data.Tagged                (Tagged (..))
 import Data.Version               (showVersion)
 
